@@ -6,12 +6,18 @@ package Bio::AssemblyImprovement::FillGaps::GapFiller::Config;
 use Moose;
 
 has 'input_files'     => ( is => 'ro', isa => 'ArrayRef', required => 1 );
-has 'insert_size'     => ( is => 'ro', isa => 'Int',      required => 1 );
+has 'insert_size'     => ( is => 'rw', isa => 'Int',      required => 1 );
+has '_default_insert_size' => ( is => 'ro', isa => 'Int',      default => 300 );
 has 'mapper'          => ( is => 'ro', isa => 'Str',      default  => 'bwa' );
 has 'output_filename' => ( is => 'rw', isa => 'Str',      default  => '_gap_filler.config' );
 
 sub create_config_file {
     my ($self) = @_;
+    
+    if(!defined($self->insert_size) || $self->insert_size == 0 )
+    {
+      $self->insert_size($self->_default_insert_size);
+    }
 
     my $input_file_names = join( ' ', @{ $self->input_files } );
     open( my $lib_fh, "+>", $self->output_filename );
@@ -36,7 +42,7 @@ Bio::AssemblyImprovement::FillGaps::GapFiller::Config - Create the config file t
 
 =head1 VERSION
 
-version 1.131890
+version 1.132610
 
 =head1 SYNOPSIS
 
