@@ -13,6 +13,7 @@ with 'Bio::AssemblyImprovement::Scaffold::SSpace::TempDirectoryRole';
 has 'input_files'     => ( is => 'ro', isa => 'ArrayRef', required => 1 );
 has 'insert_size'     => ( is => 'ro', isa => 'Int',      required => 1 );
 has 'merge_size'      => ( is => 'ro', isa => 'Int',      default  => 10 );
+has 'threads'		  => ( is => 'ro', isa => 'Int',      default  => 1  );
 has 'scaffolder_exec' => ( is => 'rw', isa => 'Str',      required => 1 );
 has 'debug'           => ( is => 'ro', isa => 'Bool', default => 0);
 
@@ -50,6 +51,7 @@ sub run {
                 '-s', $self->input_assembly, 
                 '-x', 1, 
                 '-k', $self->merge_size, 
+                '-T', $self->threads,
                 '-b', $self->_output_prefix,
                 $stdout_of_program
             )
@@ -74,7 +76,7 @@ Bio::AssemblyImprovement::Scaffold::SSpace::Main - Run one iteration of SSpace
 
 =head1 VERSION
 
-version 1.131890
+version 1.132610
 
 =head1 SYNOPSIS
 
