@@ -16,18 +16,19 @@ with 'Bio::AssemblyImprovement::Util::ZipFileRole';
 with 'Bio::AssemblyImprovement::Util::UnzipFileIfNeededRole';
 
 has 'input_filename'   => ( is => 'ro', isa => 'Str' , required => 1 );
+has 'single_cell'      => ( is => 'ro', isa => 'Bool', default => 0);
 
 
 # sub draw_histogram_of_read_lengths {
 # 	my ($self) = @_;
-# 	
+#
 # 	my $fastq_file = $self->_gunzip_file_if_needed( $self->input_filename );
-# 	
+#
 # 	my $arrayref = $self->_get_read_lengths($fastq_file);
-# 	
+#
 # 	# Set graph details
-# 	my $graph = new GD::Graph::histogram(400,600);	
-# 	$graph->set( 
+# 	my $graph = new GD::Graph::histogram(400,600);
+# 	$graph->set(
 #                 x_label         => 'Read length',
 #                 y_label         => 'Number of reads',
 #                 title           => 'Histogram of read lengths for '.$self->input_filename,
@@ -36,7 +37,7 @@ has 'input_filename'   => ( is => 'ro', isa => 'Str' , required => 1 );
 #                 shadow_depth    => 1,
 #                 shadowclr       => 'dred',
 #                 transparent     => 0,
-#     ) 
+#     )
 #     or warn $graph->error;
 #     #Draw the graph
 #     my $gd = $graph->plot($arrayref) or die $graph->error;
@@ -44,40 +45,46 @@ has 'input_filename'   => ( is => 'ro', isa => 'Str' , required => 1 );
 #     open(IMG, '>histogram.png') or die "Could not open a file called histogram.png";
 #     binmode IMG;
 #     print IMG $gd->png;
-#     
+#
 #     $self->_cleaup_after_ourselves($fastq_file);
-# 	
-#   
+#
+#
 # }
 
 sub calculate_kmer_sizes {
 
 	my ($self) = @_;
+    my %kmer_size;
 	
-	my $fastq_file = $self->_gunzip_file_if_needed( $self->input_filename );
-		
-	my $arrayref = $self->_get_read_lengths($fastq_file);
-	my $median = median(@$arrayref);
-	
-	# Set a minimum median so that the min kmer length stays at a reasonable value
-	if($median < 30){
-		$median = 30;
-	}
+    if ($self->single_cell) {
+        my $read_length = $self->first_read_length();
+        $kmer_size{min} = int($read_length * 0.5);
+        $kmer_size{max} = int($read_length * 0.95);
+    }
+    else {
+        my $fastq_file = $self->_gunzip_file_if_needed( $self->input_filename );
 
-	my %kmer_size;
-	
-	$kmer_size{min} = int($median*0.66); #66% of median read length will be minimum kmer length
-  	$kmer_size{max} = int($median*0.90); #90% of median read length will be maximum kmer length
-  
-  	if($kmer_size{min} % 2 == 0){
-    	$kmer_size{min}--;
-  	}
-  	
-  	if($kmer_size{max} % 2 == 0){
-    	$kmer_size{max}--;
-  	}
-  	
-    $self->_cleaup_after_ourselves($fastq_file);
+        my $arrayref = $self->_get_read_lengths($fastq_file);
+        my $median = median(@$arrayref);
+
+        # Set a minimum median so that the min kmer length stays at a reasonable value
+        if($median < 30){
+            $median = 30;
+        }
+
+        $kmer_size{min} = int($median*0.66); #66% of median read length will be minimum kmer length
+        $kmer_size{max} = int($median*0.90); #90% of median read length will be maximum kmer length
+
+        $self->_cleaup_after_ourselves($fastq_file);
+    }
+
+    if($kmer_size{min} % 2 == 0){
+        $kmer_size{min}--;
+    }
+
+    if($kmer_size{max} % 2 == 0){
+        $kmer_size{max}--;
+    }
   	
   	return %kmer_size;
 	
@@ -94,7 +101,7 @@ sub calculate_coverage {
 	my $total_length_of_reads = 0;
 	$total_length_of_reads += $_ for @$arrayref;
 	my $coverage = $total_length_of_reads/$expected_genome_size;
-	$coverage = sprintf ("%.0f", $coverage);	# Rounding it up 
+	$coverage = sprintf ("%.0f", $coverage);	# Rounding it up
 	
 	$self->_cleaup_after_ourselves($fastq_file);
   	
@@ -117,14 +124,14 @@ sub split_fastq {
 	my $forward_fastq = Bio::SeqIO->new( -file => ">$outfile_forward" , -format => 'Fastq' );
 	my $reverse_fastq = Bio::SeqIO->new( -file => ">$outfile_reverse" , -format => 'Fastq' );
 
-    while(my $seq = $fastq_obj->next_seq()){    
+    while(my $seq = $fastq_obj->next_seq()){
 		# Example ID: @IL9_4021:8:1:8:1892#7/1
     	if($seq->id() =~ m/\/1$/ ){
-    		$forward_fastq->write_seq($seq);   	
+    		$forward_fastq->write_seq($seq);
     	}else{
-    		$reverse_fastq->write_seq($seq);   	
+    		$reverse_fastq->write_seq($seq);
     	
-    	}	   
+    	}
     }
 
 	$self->_cleaup_after_ourselves($fastq_file);
@@ -144,6 +151,25 @@ sub _cleaup_after_ourselves {
 }
 
 
+# Returns the length of the first read in the file
+sub first_read_length {
+    my ($self) = @_;
+    my $fastq_obj;
+
+    if ( $self->input_filename =~ /\.fq$/ || $self->input_filename =~ /\.fastq$/  ) {
+    	$fastq_obj =  Bio::SeqIO->new( -file => $self->input_filename , -format => 'Fastq');
+    }
+    elsif ( $self->input_filename =~ /\.fq\.gz$/ || $self->input_filename =~ /\.fastq\.gz$/  ) {
+    	$fastq_obj =  Bio::SeqIO->new( -file => "gunzip -c " . $self->input_filename . " |" , -format => 'Fastq');
+    }
+    else {
+        die "File '$self->input_filename' not recognised as fastq. Needs to end in .fastq[.gz] or .fq[.gz]";
+    }
+
+    my $seq = $fastq_obj->next_seq();
+    return length($seq->seq());
+}
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
@@ -158,7 +184,7 @@ Bio::AssemblyImprovement::Util::FastqTools - Take a fastq file and calculate som
 
 =head1 VERSION
 
-version 1.131890
+version 1.132610
 
 =head1 SYNOPSIS
 
